@@ -185,6 +185,12 @@ class PushRequest(RpcRequest):
 	def set_iOSBadge(self,iOSBadge):
 		self.add_query_param('iOSBadge',iOSBadge)
 
+	def get_iOSSilentNotification(self):
+		return self.get_query_params().get('iOSSilentNotification')
+
+	def set_iOSSilentNotification(self,iOSSilentNotification):
+		self.add_query_param('iOSSilentNotification',iOSSilentNotification)
+
 	def get_iOSSubtitle(self):
 		return self.get_query_params().get('iOSSubtitle')
 
